@@ -1,16 +1,16 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "customtoolspluginmanager.h"
 #include "customtoolsplugin.h"
+#include "pimcommon_debug.h"
 
 #include <KPluginFactory>
 #include <KPluginMetaData>
 
-#include <QDebug>
 #include <QFileInfo>
 #include <QSet>
 
@@ -76,7 +76,7 @@ void CustomToolsPluginManagerPrivate::initializePluginList()
             mPluginList.push_back(info);
             unique.insert(info.saveName());
         } else {
-            qWarning() << "Plugin " << info.metaData.name() << " doesn't have correction plugin version. It will not be loaded.";
+            qCWarning(PIMCOMMON_LOG) << "Plugin " << info.metaData.name() << " doesn't have correction plugin version. It will not be loaded.";
         }
     }
     QVector<CustomToolsPluginInfo>::iterator end(mPluginList.end());
